cmoncrawl.processor.pipeline.streamer.StreamerDummy.stream
==========================================================

.. currentmodule:: cmoncrawl.processor.pipeline.streamer

.. automethod:: StreamerDummy.stream